@@ -29,8 +29,10 @@ CodeMirror.modeInfo = [
   {name: 'TypeScript', mime: 'application/typescript', mode: 'javascript'},
   {name: 'Jinja2', mime: 'jinja2', mode: 'jinja2'},
   {name: 'LESS', mime: 'text/x-less', mode: 'less'},
+  {name: 'LiveScript', mime: 'text/x-livescript', mode: 'livescript'},
   {name: 'Lua', mime: 'text/x-lua', mode: 'lua'},
   {name: 'Markdown (GitHub-flavour)', mime: 'text/x-markdown', mode: 'markdown'},
+  {name: 'mIRC', mime: 'text/mirc', mode: 'mirc'},
   {name: 'NTriples', mime: 'text/n-triples', mode: 'ntriples'},
   {name: 'OCaml', mime: 'text/x-ocaml', mode: 'ocaml'},
   {name: 'Pascal', mime: 'text/x-pascal', mode: 'pascal'},
@@ -47,17 +49,17 @@ CodeMirror.modeInfo = [
   {name: 'Rust', mime: 'text/x-rustsrc', mode: 'rust'},
   {name: 'Sass', mime: 'text/x-sass', mode: 'sass'},
   {name: 'Scheme', mime: 'text/x-scheme', mode: 'scheme'},
+  {name: 'SCSS', mime: 'text/x-scss', mode: 'css'},
   {name: 'Shell', mime: 'text/x-sh', mode: 'shell'},
   {name: 'Sieve', mime: 'application/sieve', mode: 'sieve'},
   {name: 'Smalltalk', mime: 'text/x-stsrc', mode: 'smalltalk'},
   {name: 'Smarty', mime: 'text/x-smarty', mode: 'smarty'},
   {name: 'SPARQL', mime: 'application/x-sparql-query', mode: 'sparql'},
   {name: 'SQL', mime: 'text/x-sql', mode: 'sql'},
-  {name: 'MySQL', mime: 'text/x-mysql', mode: 'sql'},
   {name: 'MariaDB', mime: 'text/x-mariadb', mode: 'sql'},
-  {name: 'PL/SQL', mime: 'text/x-plsql', mode: 'sql'},
   {name: 'sTeX', mime: 'text/x-stex', mode: 'stex'},
   {name: 'LaTeX', mime: 'text/x-latex', mode: 'stex'},
+  {name: 'Tcl', mime: 'text/x-tcl', mode: 'tcl'},
   {name: 'TiddlyWiki ', mime: 'text/x-tiddlywiki', mode: 'tiddlywiki'},
   {name: 'Tiki wiki', mime: 'text/tiki', mode: 'tiki'},
   {name: 'VB.NET', mime: 'text/x-vb', mode: 'vb'},
